# Tinkoff Acquiring API

The Tinkoff Acquiring API library provides convenient access to the [Tinkoff Acquiring API](https://www.tinkoff.ru/kassa/develop/api/payments/) from applications written in the Python language.

[![pypi](https://img.shields.io/pypi/v/tinkoff-acquiring-api.svg)](https://pypi.python.org/pypi/tinkoff-acquiring-api)
[![Test Result](https://github.com/saliy/tinkoff-acquiring-api/actions/workflows/test.yml/badge.svg)](https://github.com/saliy/tinkoff-acquiring-api/actions/workflows/test.yml)
[![Release Result](https://github.com/saliy/tinkoff-acquiring-api/actions/workflows/release.yml/badge.svg)](https://github.com/saliy/tinkoff-acquiring-api/actions/workflows/test.yml)


## Installation
If you just want to use the package, just run:

```sh
pip install --upgrade tinkoff-acquiring-api
```

### Requirements
Python 3.6+ (PyPy supported)

## Usage
...
